-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

local M = {}
M.type = "auxilliary"
M.relevantDevice = nil

local htmlTexture = require("htmlTexture")

local min = math.min
local max = math.max

local gaugesScreenName = nil
local htmlPath = nil

local updateTimer = 0
local updateFPS = 60
local invFPS = 1 / updateFPS

local function updateGFX(dt)
  updateTimer = updateTimer + dt
  if updateTimer > invFPS then
    local data = {}

    local maxRPM = 0

    if powertrain.getDevicesByCategory("engine")[1] then
      maxRPM = powertrain.getDevicesByCategory("engine")[1].maxRPM
    end

    local rpmColorDecide = math.ceil(electrics.values.rpm) / (maxRPM / 10)
    if rpmColorDecide >= 7.5 and rpmColorDecide < 9.3 then
      htmlTexture.call(gaugesScreenName, "updateRPMColors", "rgb(255, 196, 0)")
    elseif rpmColorDecide >= 9.3 then
      htmlTexture.call(gaugesScreenName, "updateRPMColors", "rgb(255, 0, 0)")
    else
      htmlTexture.call(gaugesScreenName, "updateRPMColors", "rgb(255, 255, 255)")
    end

    local gear = electrics.values.gear
    if gear == 0 then
      gear = "N"
    elseif gear < 0 then
      gear = "R"
    end

    local oiltemp = electrics.values.oiltemp
    if oiltemp >= 94 and oiltemp < 104 then
      htmlTexture.call(gaugesScreenName, "updateOiltempColors", "rgb(255, 196, 0)")
    elseif oiltemp >= 104 then
      htmlTexture.call(gaugesScreenName, "updateOiltempColors", "rgb(255, 0, 0)")
    else
      htmlTexture.call(gaugesScreenName, "updateOiltempColors", "rgb(255, 255, 255)")
    end

    data.gear = gear
    data.oiltemp = math.ceil(electrics.values.oiltemp) or 0
    data.speed = electrics.values.wheelspeed or 0
    data.rpm = math.ceil(electrics.values.rpm) or 0
    --dump(data)

    htmlTexture.call(gaugesScreenName, "updateData", data)
    updateTimer = 0
  end
end

local function init(jbeamData)
  gaugesScreenName = "@bolide_aftermarket_race_gauge"
  htmlPath = "local://local/vehicles/bolide/digital_race_gauge/bolide_aftermarket_race_gauge.html"
  local unitType = jbeamData.unitType or "metric"
  local width = jbeamData.textureWidth or 1024
  local height = jbeamData.textureHeight or 459

  if htmlPath then
    htmlTexture.create(gaugesScreenName, htmlPath, width, height, updateFPS, 'automatic')
    htmlTexture.call(gaugesScreenName, "setUnits", {unitType = unitType})
  else
    log("E", "bolideGauges", "Got no html path for the texture, can't display anything...")
    M.updateGFX = nop
  end
end

M.init = init
M.updateGFX = updateGFX

return M